@@ -18,7 +18,7 @@ Files in this module should only be used for testing, not production.
 
 from .sample_files import (EXAMPLE_SONDE1, EXAMPLE_LCL1,
                            EXAMPLE_SONDE_WILDCARD, EXAMPLE_MET1,
-                           EXAMPLE_METE40,
+                           EXAMPLE_METE40, EXAMPLE_TWP_SONDE_20060121,
                            EXAMPLE_MET_WILDCARD, EXAMPLE_CEIL1,
                            EXAMPLE_CEIL_WILDCARD, EXAMPLE_ANL_CSV,
                            EXAMPLE_MPL_1SAMPLE, EXAMPLE_IRT25m20s,
